__all__ = 'APIClient'

from abc import abstractmethod


class APIClient:

    def __init__(self, plugin):
        self._plugin = plugin
        self._signed_in_user = None

    def get_plugin(self):
        return self._plugin

    def sign_in(self, user, skip_validation=False):

        if not skip_validation:
            self.validate_credentials(user.get_auth_email(), user.get_auth_key())

        self._signed_in_user = user

        # add the user to the saved profiles list if not already added
        user_container = self.get_plugin().get_preferences_container().get_user_container()
        profiles = user_container.get_all()

        for profile in profiles:
            if profile.get_auth_email() == user.get_auth_email() and profile.get_auth_key() == user.get_auth_key():
                return None

        user_container.append(user)

    def sign_out(self):
        self._signed_in_user = None

    def is_user_signed_in(self):
        return self._signed_in_user is not None

    @abstractmethod
    def connected(self):
        raise NotImplementedError

    def get_signed_in_user(self):
        if self.is_user_signed_in():
            return self._signed_in_user
        return None

    @abstractmethod
    def get_api_schema(self, factory_collection):
        raise NotImplementedError

    @staticmethod
    @abstractmethod
    def validate_credentials(auth_email, auth_access_key):
        raise NotImplementedError

    @abstractmethod
    def upload_project(self,
                       packed_project,
                       upload_root_dir,
                       delete_local_files_after_upload=False):
        raise NotImplementedError

    @abstractmethod
    def submit_new_project(self,
                           packed_project,
                           job_preset,
                           delete_local_files_after_upload=False):
        raise NotImplemented

    @abstractmethod
    def submit_to_remote_project(self,
                                 remote_project,
                                 job_preset):
        raise NotImplemented

    @abstractmethod
    def update_remote_project_status(self, remote_project):
        raise NotImplemented

    @abstractmethod
    def get_products(self, ignore_cache=False):
        raise NotImplementedError

    @abstractmethod
    def get_products_with_app_type(self, app_type):
        raise NotImplementedError

    @abstractmethod
    def get_product_app_types(self, ignore_cache=False):
        raise NotImplementedError

    @abstractmethod
    def get_user_info(self, ignore_cache=False):
        raise NotImplementedError

    @abstractmethod
    def get_machines(self,
                     app,
                     operation,
                     plugins=None,
                     ignore_cache=False):
        raise NotImplementedError
