import pathlib
from PySide2 import QtCore
from PySide2 import QtGui
import sys
import math

REMOTE_SOURCE_SUFFIX = "_remote"

ASSETS_DIRECTORY = pathlib.Path(__file__).parent / pathlib.Path("assets")
FONTS_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("fonts")
ICONS_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("icons")
IMAGES_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("images")

# print(QtGui.QFontDatabase.applicationFontFamilies(i))

# asset paths
SPINNER_GIF_PATH = ICONS_DIRECTORY / u"spinner.gif"
SPINNER_WHITE_GIF_PATH = ICONS_DIRECTORY / u"spinner_white.gif"
SPINNER_WHITE_2D2D2D_GIF_PATH = ICONS_DIRECTORY / u"spinner_white_2d2d2d.gif"
SPINNER_WHITE_666666_GIF_PATH = ICONS_DIRECTORY / u"spinner_white_666666.gif"
SPINNER_LARGE_GIF_PATH = ICONS_DIRECTORY / u"spinner_large.gif"
LOADING_BAR_GIF_PATH = ICONS_DIRECTORY / u"loading_bar.gif"

CHECKMARK_ICON_WHITE_PATH = ICONS_DIRECTORY / u"checkmark_icon_white.png"
CHECKMARK_ICON_BLACK_PATH = ICONS_DIRECTORY / u"checkmark_icon_black.png"
CHECKMARK_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"checkmark_icon_off_white.png"

DIRECTORY_ICON_WHITE_PATH = ICONS_DIRECTORY / u"directory_icon_white.png"
DIRECTORY_ICON_BLACK_PATH = ICONS_DIRECTORY / u"directory_icon_black.png"
DIRECTORY_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"directory_icon_off_white.png"

EYE_ICON_WHITE_PATH = ICONS_DIRECTORY / u"eye_icon_white.png"
EYE_ICON_BLACK_PATH = ICONS_DIRECTORY / u"eye_icon_black.png"
EYE_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"eye_icon_off_white.png"

GM_ICON_WHITE_PATH = ICONS_DIRECTORY / u"gm_icon_white.png"
GM_ICON_BLACK_PATH = ICONS_DIRECTORY / u"gm_icon_black.png"
GM_ICON_BLACK_AND_WHITE_PATH = ICONS_DIRECTORY / u"gm_icon_black_and_white.png"
GM_MAYA_ICON_PATH = ICONS_DIRECTORY / u"gm_maya_icon.png"

USER_ICON_WHITE_PATH = ICONS_DIRECTORY / u"user_icon_white.png"
USER_ICON_BLACK_PATH = ICONS_DIRECTORY / u"user_icon_black.png"
USER_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"user_icon_off_white.png"

TRASH_ICON_WHITE_PATH = ICONS_DIRECTORY / u"trash_icon_white.png"
TRASH_ICON_BLACK_PATH = ICONS_DIRECTORY / u"trash_icon_black.png"
TRASH_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"trash_icon_off_white.png"

MENU_ICON_WHITE_PATH = ICONS_DIRECTORY / u"menu_icon_white.png"
MENU_ICON_BLACK_PATH = ICONS_DIRECTORY / u"menu_icon_black.png"
MENU_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"menu_icon_off_white.png"

NEW_JOB_PRESET_ICON_WHITE_PATH = ICONS_DIRECTORY / u"new_job_preset_icon_white.png"
NEW_JOB_PRESET_ICON_BLACK_PATH = ICONS_DIRECTORY / u"new_job_preset_icon_black.png"
NEW_JOB_PRESET_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"new_job_preset_icon_off_white.png"

LOCKED_ICON_WHITE_PATH = ICONS_DIRECTORY / u"locked_icon_white.png"
LOCKED_ICON_BLACK_PATH = ICONS_DIRECTORY / u"locked_icon_black.png"
LOCKED_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"locked_icon_off_white.png"

UNLOCKED_ICON_WHITE_PATH = ICONS_DIRECTORY / u"unlocked_icon_white.png"
UNLOCKED_ICON_BLACK_PATH = ICONS_DIRECTORY / u"unlocked_icon_black.png"
UNLOCKED_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"unlocked_icon_off_white.png"

INFO_ICON_WHITE_PATH = ICONS_DIRECTORY / u"info_icon_white.png"
INFO_ICON_BLACK_PATH = ICONS_DIRECTORY / u"info_icon_black.png"
INFO_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"info_icon_off_white.png"

FILE_ICON_WHITE_PATH = ICONS_DIRECTORY / u"file_icon_white.png"
FILE_ICON_BLACK_PATH = ICONS_DIRECTORY / u"file_icon_black.png"

NEW_FILE_ICON_WHITE_PATH = ICONS_DIRECTORY / u"new_file_icon_white.png"
NEW_FILE_ICON_BLACK_PATH = ICONS_DIRECTORY / u"new_file_icon_black.png"
NEW_FILE_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"new_file_icon_off_white.png"

COPY_ICON_WHITE_PATH = ICONS_DIRECTORY / u"copy_icon_white.png"
COPY_ICON_BLACK_PATH = ICONS_DIRECTORY / u"copy_icon_black.png"
COPY_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"copy_icon_off_white.png"

CONSOLE_ICON_WHITE_PATH = ICONS_DIRECTORY / u"console_icon_white.png"
CONSOLE_ICON_BLACK_PATH = ICONS_DIRECTORY / u"console_icon_black.png"
CONSOLE_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"console_icon_off_white.png"

UP_ARROW_ICON_WHITE_PATH = ICONS_DIRECTORY / u"up_arrow_icon_white.png"
UP_ARROW_ICON_BLACK_PATH = ICONS_DIRECTORY / u"up_arrow_icon_black.png"
UP_ARROW_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"up_arrow_icon_off_white.png"
UP_ARROW_ICON_OFF_BLACK_PATH = ICONS_DIRECTORY / u"up_arrow_icon_off_black.png"

DOWN_ARROW_ICON_WHITE_PATH = ICONS_DIRECTORY / u"down_arrow_icon_white.png"
DOWN_ARROW_ICON_BLACK_PATH = ICONS_DIRECTORY / u"down_arrow_icon_black.png"
DOWN_ARROW_ICON_OFF_WHITE_PATH = ICONS_DIRECTORY / u"down_arrow_icon_off_white.png"
DOWN_ARROW_ICON_OFF_BLACK_PATH = ICONS_DIRECTORY / u"down_arrow_icon_off_black.png"

RIGHT_ARROW_ICON_OFF_BLACK_PATH = ICONS_DIRECTORY / u"right_arrow_icon_off_black.png"

LEFT_ARROW_ICON_OFF_BLACK_PATH = ICONS_DIRECTORY / u"left_arrow_icon_off_black.png"

DOWN_ARROW_2_ICON_WHITE_PATH = ICONS_DIRECTORY / u"down_arrow_2_icon_white.png"
DOWN_ARROW_2_ICON_BRAND_PATH = ICONS_DIRECTORY / u"down_arrow_2_icon_brand.png"

RIGHT_ARROW_2_ICON_WHITE_PATH = ICONS_DIRECTORY / u"right_arrow_2_icon_white.png"
RIGHT_ARROW_2_ICON_BRAND_PATH = ICONS_DIRECTORY / u"right_arrow_2_icon_brand.png"


BLENDER_ICON_PATH = ICONS_DIRECTORY / u"blender_icon.png"
MAYA_ICON_PATH = ICONS_DIRECTORY / u"maya_icon.png"
MOE_ICON_PATH = ICONS_DIRECTORY / u"moe_icon.png"
VRAY_ICON_PATH = ICONS_DIRECTORY / u"vray_icon.png"
EMPTY_ICON_PATH = ICONS_DIRECTORY / u"empty_icon.png"


# icons
SPINNER_GIF = unicode(SPINNER_GIF_PATH)
SPINNER_LARGE_GIF = unicode(SPINNER_LARGE_GIF_PATH)
LOADING_BAR_GIF = unicode(LOADING_BAR_GIF_PATH)

CHECKMARK_ICON_WHITE = QtGui.QIcon(unicode(CHECKMARK_ICON_WHITE_PATH))
CHECKMARK_ICON_BLACK = QtGui.QIcon(unicode(CHECKMARK_ICON_BLACK_PATH))
CHECKMARK_ICON_OFF_WHITE = QtGui.QIcon(unicode(CHECKMARK_ICON_OFF_WHITE_PATH))

DIRECTORY_ICON_WHITE = QtGui.QIcon(unicode(DIRECTORY_ICON_WHITE_PATH))
DIRECTORY_ICON_BLACK = QtGui.QIcon(unicode(DIRECTORY_ICON_BLACK_PATH))
DIRECTORY_ICON_OFF_WHITE = QtGui.QIcon(unicode(DIRECTORY_ICON_OFF_WHITE_PATH))

EYE_ICON_WHITE = QtGui.QIcon(unicode(EYE_ICON_WHITE_PATH))
EYE_ICON_BLACK = QtGui.QIcon(unicode(EYE_ICON_BLACK_PATH))
EYE_ICON_OFF_WHITE = QtGui.QIcon(unicode(EYE_ICON_OFF_WHITE_PATH))

GM_ICON_WHITE = QtGui.QIcon(unicode(GM_ICON_WHITE_PATH))
GM_ICON_BLACK = QtGui.QIcon(unicode(GM_ICON_BLACK_PATH))
GM_ICON_BLACK_AND_WHITE = QtGui.QIcon(unicode(GM_ICON_BLACK_AND_WHITE_PATH))
GM_MAYA_ICON = QtGui.QIcon(unicode(GM_MAYA_ICON_PATH))

USER_ICON_WHITE = QtGui.QIcon(unicode(USER_ICON_WHITE_PATH))
USER_ICON_BLACK = QtGui.QIcon(unicode(USER_ICON_BLACK_PATH))
USER_ICON_OFF_WHITE = QtGui.QIcon(unicode(USER_ICON_OFF_WHITE_PATH))

TRASH_ICON_WHITE = QtGui.QIcon(unicode(TRASH_ICON_WHITE_PATH))
TRASH_ICON_BLACK = QtGui.QIcon(unicode(TRASH_ICON_BLACK_PATH))
TRASH_ICON_OFF_WHITE = QtGui.QIcon(unicode(TRASH_ICON_OFF_WHITE_PATH))

MENU_ICON_WHITE = QtGui.QIcon(unicode(MENU_ICON_WHITE_PATH))
MENU_ICON_BLACK = QtGui.QIcon(unicode(MENU_ICON_BLACK_PATH))
MENU_ICON_OFF_WHITE = QtGui.QIcon(unicode(MENU_ICON_OFF_WHITE_PATH))

NEW_JOB_PRESET_ICON_WHITE = QtGui.QIcon(unicode(NEW_JOB_PRESET_ICON_WHITE_PATH))
NEW_JOB_PRESET_ICON_BLACK = QtGui.QIcon(unicode(NEW_JOB_PRESET_ICON_BLACK_PATH))
NEW_JOB_PRESET_ICON_OFF_WHITE = QtGui.QIcon(unicode(NEW_JOB_PRESET_ICON_OFF_WHITE_PATH))

LOCKED_ICON_WHITE = QtGui.QIcon(unicode(LOCKED_ICON_WHITE_PATH))
LOCKED_ICON_BLACK = QtGui.QIcon(unicode(LOCKED_ICON_BLACK_PATH))
LOCKED_ICON_OFF_WHITE = QtGui.QIcon(unicode(LOCKED_ICON_OFF_WHITE_PATH))

UNLOCKED_ICON_WHITE = QtGui.QIcon(unicode(UNLOCKED_ICON_WHITE_PATH))
UNLOCKED_ICON_BLACK = QtGui.QIcon(unicode(UNLOCKED_ICON_BLACK_PATH))
UNLOCKED_ICON_OFF_WHITE = QtGui.QIcon(unicode(UNLOCKED_ICON_OFF_WHITE_PATH))

INFO_ICON_WHITE = QtGui.QIcon(unicode(INFO_ICON_WHITE_PATH))
INFO_ICON_BLACK = QtGui.QIcon(unicode(INFO_ICON_BLACK_PATH))
INFO_ICON_OFF_WHITE = QtGui.QIcon(unicode(INFO_ICON_OFF_WHITE_PATH))

FILE_ICON_WHITE = QtGui.QIcon(unicode(FILE_ICON_WHITE_PATH))
FILE_ICON_BLACK = QtGui.QIcon(unicode(FILE_ICON_BLACK_PATH))

NEW_FILE_ICON_WHITE = QtGui.QIcon(unicode(NEW_FILE_ICON_WHITE_PATH))
NEW_FILE_ICON_BLACK = QtGui.QIcon(unicode(NEW_FILE_ICON_BLACK_PATH))
NEW_FILE_ICON_OFF_WHITE = QtGui.QIcon(unicode(NEW_FILE_ICON_OFF_WHITE_PATH))

COPY_ICON_WHITE = QtGui.QIcon(unicode(COPY_ICON_WHITE_PATH))
COPY_ICON_BLACK = QtGui.QIcon(unicode(COPY_ICON_BLACK_PATH))
COPY_ICON_OFF_WHITE = QtGui.QIcon(unicode(COPY_ICON_OFF_WHITE_PATH))

CONSOLE_ICON_WHITE = QtGui.QIcon(unicode(CONSOLE_ICON_WHITE_PATH))
CONSOLE_ICON_BLACK = QtGui.QIcon(unicode(CONSOLE_ICON_BLACK_PATH))
CONSOLE_ICON_OFF_WHITE = QtGui.QIcon(unicode(CONSOLE_ICON_OFF_WHITE_PATH))

UP_ARROW_ICON_WHITE = QtGui.QIcon(unicode(UP_ARROW_ICON_WHITE_PATH))
UP_ARROW_ICON_BLACK = QtGui.QIcon(unicode(UP_ARROW_ICON_BLACK_PATH))
UP_ARROW_ICON_OFF_WHITE = QtGui.QIcon(unicode(UP_ARROW_ICON_OFF_WHITE_PATH))

BLENDER_ICON = QtGui.QIcon(unicode(BLENDER_ICON_PATH))
MAYA_ICON = QtGui.QIcon(unicode(MAYA_ICON_PATH))
MOE_ICON = QtGui.QIcon(unicode(MOE_ICON_PATH))
VRAY_ICON = QtGui.QIcon(unicode(VRAY_ICON_PATH))
EMPTY_ICON = QtGui.QIcon(unicode(EMPTY_ICON_PATH))

# images
GRIDMARKETS_IMAGE = QtGui.QPixmap(unicode(IMAGES_DIRECTORY / u"gridmarkets_image.png"))

DEFAULT_TOP_BANNER_SHORT_IMAGE = QtGui.QPixmap(unicode(IMAGES_DIRECTORY / u"top_banner_short.png"))
DEFAULT_TOP_BANNER_WIDE_IMAGE = QtGui.QPixmap(unicode(IMAGES_DIRECTORY / u"top_banner_wide.png"))



# the url of the render manager
REGISTER_ACCOUNT_LINK = "https://portal.gridmarkets.com/init/default/register"
FORGOT_PASSWORD_URL = "https://portal.gridmarkets.com/init/default/lost_password"
RENDER_MANAGER_URL = "https://portal.gridmarkets.com"
COST_CALCULATOR_URL = "https://www.gridmarkets.com/calculator"
FAQ_URL = "https://www.gridmarkets.com/faq"
SECURITY_URL = "https://www.gridmarkets.com/security"
GRIDMARKETS_WEBSITE_URL = "https://www.gridmarkets.com/"
ENVOY_URL = "https://www.gridmarkets.com/envoy"
ENVOY_LOGS_URL = "http://localhost:8090/logs"
SUPPORT_EMAIL = "support@gridmarkets.com"

CURRENT_SCENE_PROJECT_OPTION_INDEX = -1

DEFAULT_MAX_SIZE = 16777215

# These are the max int values for qt which may be different from sys.maxint
# use 32 bit max int values
MAX_INT = math.pow(2, 31) - 1
MIN_INT = -MAX_INT - 1

AVAILABLE_CREDITS_SUFFIX = u" Credits"
AVAILABLE_CREDITS_DECIMAL_PLACES = 2
AVAILABLE_CREDITS_TIMER_INTERVAL = 10000
RELOAD_SCENE_SETTINGS_SLEEP_INTERVAL = 1

MAYA_FILE_EXTENSION = u'.mb'
MARGIN_SIZE = 25
MAX_TOP_BANNER_WIDTH = MARGIN_SIZE*2 + 10


class STYLE_PROPS:
    H1 = 'h1'
    H2 = 'h2'
    H3 = 'h3'
    H4 = 'h4'
    H5 = 'h5'
    BRAND = 'brand'
    POPUP = 'popup'
    CONSOLE = "console"
    HEADER = 'header'
    TOOL_TIP = 'tool-tip'
    LEFT_BANNER = 'left-banner'
    BACKGROUND_LEVEL_0 = 'background-level-0'
    BACKGROUND_LEVEL_1 = 'background-level-1'
    BACKGROUND_LEVEL_2 = 'background-level-2'
    MAIN_CONTAINER_WIDGET = 'main-container-widget'


MOUSE_CURSOR_SIZE = QtCore.QSize(16,16)


class MOUSE_CURSORS:
    GM_ICON = QtGui.QCursor(GM_ICON_BLACK.pixmap(MOUSE_CURSOR_SIZE))


GLOBAL_STYLE_SHEET_OLD = u"""
QDialog[popup=true]{
    background: #404040;
}

QMenu[inPopup]{
    border: 0px;
    width: 999;
}

QLabel[userNameHeader=true]{
    font-size: 14px;
}

QLabel[invalid=true]{
    color: red;
}

QPushButton::menu-indicator[noMenuIndicator=true] {
    image: none;
}

QTextEdit[console=true]{
    font-family: "Consolas", "Liberation Mono", "Courier New", "Courier";
}

QSplitter::handle {
    image: none;
}

QGroupBox[inner-group-box=true]{
    border: 15px solid transparent;
    border-radius: 6px;
    background: #4f4f4f;
}

/*
QLineEdit[urgent=true]{
    border: 2px solid gray;
    border-radius: 10px;
    padding: 0 8px;
    background: yellow;
    selection-background-color: darkgray;
}

QLineEdit:focus {
    background: red;
}
*/
"""

BRAND_COLOR_KEY = "BRAND_COLOR"
BRAND_COLOR_HIGHLIGHT_KEY = "BRAND_COLOR_HIGHLIGHT"
FOREGROUND_COLOR_KEY = "FOREGROUND_COLOR"
BACKGROUND_COLOR_KEY = "BACKGROUND_COLOR"
COLOR_DISABLED_KEY = "COLOR_DISABLED"
BORDER_COLOR_KEY = "BORDER_COLOR"
BORDER_COLOR_HOVER_KEY = "BORDER_COLOR_HOVER"
BORDER_COLOR_DISABLED_KEY = "BORDER_COLOR_DISABLED"
PLACEHOLDER_TEXT_COLOR_KEY = "PLACEHOLDER_TEXT_COLOR"
CONSOLE_BACKGROUND_COLOR_KEY = "CONSOLE_BACKGROUND_COLOR"

class WhiteTheme:
    WHITE = u'white'
    GREY_01 = u'#f3f3f3'
    BLACK = u'black'
    BRAND_COLOR = u'#38b6ff'
    BRAND_COLOR_HIGHLIGHT = u'#6cc7fc'
    FOREGROUND_COLOR = u'black'
    FOREGROUND_COLOR_2 = u'#333333'
    FOREGROUND_COLOR_3 = u'#4e4e4e'
    BACKGROUND_COLOR_0 = u'white'
    BACKGROUND_COLOR_1 = u'white'
    BACKGROUND_COLOR_2 = u'#f8f8f8'
    MENU_BACKGROUND_COLOR = BACKGROUND_COLOR_1
    ABSTRACT_ITEM_VIEW_BACKGROUND = BACKGROUND_COLOR_1
    ABSTRACT_ITEM_VIEW_ALTERNATE_BACKGROUND = BACKGROUND_COLOR_2
    COLOR_DISABLED = u'#e8e8e8'
    BACKGROUND_COLOR_DISABLED = u'#c4c4c4'
    BORDER_COLOR = u'#c9c9c9'
    BORDER_COLOR_HOVER = u'#494949'
    BORDER_COLOR_DISABLED = COLOR_DISABLED
    LEFT_BANNER_BACKGROUND_COLOR = u"#dddddd"
    PLACEHOLDER_TEXT_COLOR = u'#222222'
    CONSOLE_BACKGROUND_COLOR = u'#232323'
    CHECK_BOX_CHECKED_BACKGROUND_COLOR = BLACK
    CHECK_BOX_CHECKED_BORDER_COLOR = BLACK
    CHECK_BOX_CHECKED__HOVER_BACKGROUND_COLOR = u'#313131'
    CHECK_BOX_CHECKED__HOVER_BORDER_COLOR = u'#313131'
    PUSH_BUTTON_COLOR = u'#dddddd'
    PUSH_BUTTON_PRESSED_COLOR = u'#a5a5a5'
    SCROLL_BAR_BACKGROUND = u'#ebebeb'
    SCROLL_BAR_HANDLE_BACKGROUND = u'#c6c6c6'


class BlackTheme:
    WHITE = u'white'
    GREY_01 = u'#f3f3f3'
    BLACK = u'black'
    BRAND_COLOR = u'#38b6ff'
    BRAND_COLOR_HIGHLIGHT = u'#6cc7fc'
    FOREGROUND_COLOR = u'white'
    FOREGROUND_COLOR_2 = u'#efefef'
    FOREGROUND_COLOR_3 = u'#dbdbdb'
    BACKGROUND_COLOR_0 = u'#2d2d2d'
    BACKGROUND_COLOR_1 = u'#222222'
    BACKGROUND_COLOR_2 = u'#171717'
    MENU_BACKGROUND_COLOR = u'#333333'
    ABSTRACT_ITEM_VIEW_BACKGROUND = BACKGROUND_COLOR_1
    ABSTRACT_ITEM_VIEW_ALTERNATE_BACKGROUND = BACKGROUND_COLOR_2
    COLOR_DISABLED = u'#474747'
    BACKGROUND_COLOR_DISABLED = u'#666666'
    BORDER_COLOR = u'#5d5d5d'
    BORDER_COLOR_HOVER = u'#bababa'
    BORDER_COLOR_DISABLED = COLOR_DISABLED
    LEFT_BANNER_BACKGROUND_COLOR = u'black'
    PLACEHOLDER_TEXT_COLOR = u'#ffffff'
    CONSOLE_BACKGROUND_COLOR = BLACK
    CHECK_BOX_CHECKED_BACKGROUND_COLOR = BACKGROUND_COLOR_2
    CHECK_BOX_CHECKED_BORDER_COLOR = BORDER_COLOR
    CHECK_BOX_CHECKED__HOVER_BACKGROUND_COLOR = u'#313131'
    CHECK_BOX_CHECKED__HOVER_BORDER_COLOR = BORDER_COLOR_HOVER
    PUSH_BUTTON_COLOR = u'#565656'
    PUSH_BUTTON_PRESSED_COLOR = u'#868686'
    SCROLL_BAR_BACKGROUND = BACKGROUND_COLOR_1
    SCROLL_BAR_HANDLE_BACKGROUND = u'#717172'

"""
black
transparent

white
#f8f8f8
#ebebeb
#dddddd
#dadada
#cecece
#c6c6c6 - off white icon color
#c4c4c4
#a5a5a5

"""
