from PySide2 import QtWidgets, QtCore, QtGui


class ElidedLabel(QtWidgets.QFrame):
    elisionChanged = QtCore.Signal(bool)

    def __init__(self, text, parent=None):
        QtWidgets.QFrame.__init__(self, parent=parent)
        self.content = text
        self.elided = False

    def setText(self, newText):
        self.content = newText
        self.update()

    def text(self):
        return self.content

    def isElided(self):
        return self.elided

    def paintEvent(self, event):
        QtWidgets.QFrame.paintEvent(self, event)

        painter = QtGui.QPainter(self)
        fontMetrics = painter.fontMetrics()
        rect = self.rect()

        didElide = False
        textLayout = QtGui.QTextLayout(self.content, painter.font())
        textLayout.beginLayout()

        while True:
            line = textLayout.createLine()

            if not line.isValid():
                break

            line.setLineWidth(self.width())
            elided_line = fontMetrics.elidedText(self.content, QtCore.Qt.ElideRight, self.width())
            painter.drawText(rect, int(QtCore.Qt.AlignVCenter), elided_line)
            line = textLayout.createLine()
            didElide = line.isValid()

        textLayout.endLayout()

        if didElide != self.elided:
            self.elided = didElide
            self.elisionChanged.emit(didElide)