__all__ = 'FrameRangeInput'

from .input_widget import InputWidget
from PySide2 import QtWidgets
from PySide2 import QtCore
from gm_qt_plugin import qt_constants
from gm_qt_plugin.widgets.input_widgets.spin_box import SpinBox


class FrameRangeInput(QtWidgets.QWidget, InputWidget):

    # Don't make these too large or the spin boxes refuse to shrink (even when empty)
    MAX_FRAME_VALUE = 99999
    MIN_FRAME_VALUE = -99999

    def __init__(self, parent=None):
        QtWidgets.QWidget.__init__(self, parent=parent)

        """ Create Widgets """
        self.start_input = SpinBox()
        self.start_input.setPrefix(u"Start ")
        self.start_input.setMinimum(FrameRangeInput.MIN_FRAME_VALUE)
        self.start_input.setMaximum(FrameRangeInput.MAX_FRAME_VALUE)

        self.end_input = SpinBox()
        self.end_input.setPrefix(u"End ")
        self.end_input.setMinimum(FrameRangeInput.MIN_FRAME_VALUE)
        self.end_input.setMaximum(FrameRangeInput.MAX_FRAME_VALUE)

        self.step_input = SpinBox()
        self.step_input.setPrefix(u"Step ")
        self.step_input.setMinimum(FrameRangeInput.MIN_FRAME_VALUE)
        self.step_input.setMaximum(FrameRangeInput.MAX_FRAME_VALUE)

        # let the spin boxes shrink
        self.start_input.setMinimumSize(0,0)
        self.end_input.setMinimumSize(0,0)
        self.step_input.setMinimumSize(0,0)

        """ Create Layout """
        self.layout = QtWidgets.QHBoxLayout(self)
        self.layout.setContentsMargins(0,0,0,0)
        self.layout.addWidget(self.start_input)
        self.layout.addWidget(self.end_input)
        self.layout.addWidget(self.step_input)

        """ Create Connections """
        self.start_input.valueChanged.connect(self._catch_value_change)
        self.end_input.valueChanged.connect(self._catch_value_change)
        self.step_input.valueChanged.connect(self._catch_value_change)

    def minimumSizeHint(self):
        return QtCore.QSize(0,0)

    def get_value(self):
        return self.to_string()

    def set_value(self, value):
        frame_range = FrameRangeInput.parse_frame_range(value)
        self.start_input.setValue(frame_range[0])
        self.end_input.setValue(frame_range[1])
        self.step_input.setValue(frame_range[2])

    def to_string(self):
        return "{0} {1} {2}".format(self.start_input.value(), self.end_input.value(), self.step_input.value())

    @staticmethod
    def parse_frame_range(frame_range):
        values = frame_range.split(' ')

        try:
            start = int(values[0])
            end = int(values[1])
            step = int(values[2])
        except Exception:
            start = 0
            end = 0
            step = 0

        return start, end, step
