import pathlib
from PySide2 import QtGui

PLUGIN_NAME = "maya2gm.py"

ASSETS_DIRECTORY = pathlib.Path(__file__).parent / pathlib.Path("assets")
FONTS_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("fonts")
ICONS_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("icons")
IMAGES_DIRECTORY = ASSETS_DIRECTORY / pathlib.Path("images")

MAYA2GM_TITLE_IMAGE = QtGui.QPixmap(unicode(IMAGES_DIRECTORY / u"MAYA2GM FULL LOGO.png"))
DEFAULT_LEFT_BANNER_IMAGE = QtGui.QPixmap(unicode(IMAGES_DIRECTORY / u"left_banner.png"))
HELP_URL = "https://www.gridmarkets.com/maya"

class MayaRenderer:
    def __init__(self, commandline_name, internal_name):
        self._commandline_name = commandline_name
        self._internal_name = internal_name

    def get_commandline_name(self):
        return self._commandline_name

    def get_internal_name(self):
        return self._internal_name


class RENDERERS:
    MAYA_SOFTWARE_RENDERER = MayaRenderer('sw', 'mayaSoftware')
    MAYA_HARDWARE_RENDERER = MayaRenderer('hw', 'mayaHardware')
    MAYA_HARDWARE_2_RENDERER = MayaRenderer('hw2', 'mayaHardware2')
    MAYA_VECTOR_RENDERER = MayaRenderer('vr', 'mayaVector')
    MAYA_ARNOLD_RENDERER = MayaRenderer('arnold', 'arnold')
    MAYA_RENDERMAN_RENDERER = MayaRenderer('rman', 'rman')
    MAYA_REDSHIFT_RENDERER = MayaRenderer('redshift', 'redshift')
    MAYA_VRAY_RENDERER = MayaRenderer('vray', 'vray')


UNSUPPORTED_RENDERER = 'Unsupported Renderer'
